    require 'quickfix_ruby'
    require 'quickfix42'

    noMDEntries = Quickfix::NoMDEntries.new()
    message.getField(noMDEntries)

    group = Quickfix42::MarketDataSnapshotFullRefresh.NoMDEntries.new()
    MDEntryType = Quickfix::MDEntryType.new()
    MDEntryPx = Quickfix::MDEntryPx.new()
    MDEntrySize = Quickfix::MDEntrySize.new()
    orderID = Quickfix::OrderID.new();

    message.getGroup(1, group);
    group.getField(MDEntryType);
    group.getField(MDEntryPx);
    group.getField(MDEntrySize);
    group.getField(orderID);

    message.getGroup(2, group);
    group.getField(MDEntryType);
    group.getField(MDEntryPx);
    group.getField(MDEntrySize);
    group.getField(orderID);